Struct common_traits::AtomicF32
source · pub struct AtomicF32(/* private fields */);Trait Implementations
sourceimpl AsBytes for AtomicF32
impl AsBytes for AtomicF32
sourceconst BITS: usize = 32usize
const BITS: usize = 32usize
Convenience costant field equal to
AsBytes::BYTES * 8.sourceimpl Atomic for AtomicF32
impl Atomic for AtomicF32
type NonAtomicType = f32
type NonAtomicType = f32
The non atomic variant of this type
sourcefn new(value: Self::NonAtomicType) -> Self
fn new(value: Self::NonAtomicType) -> Self
Creates a new atomic integer.
sourcefn load(&self, order: Ordering) -> Self::NonAtomicType
fn load(&self, order: Ordering) -> Self::NonAtomicType
Loads a value from the atomic integer. Read more
sourcefn store(&self, value: Self::NonAtomicType, order: Ordering)
fn store(&self, value: Self::NonAtomicType, order: Ordering)
sourcefn get_mut(&mut self) -> &mut Self::NonAtomicType
fn get_mut(&mut self) -> &mut Self::NonAtomicType
Returns a mutable reference to the underlying integer. Read more
sourcefn into_inner(self) -> Self::NonAtomicType
fn into_inner(self) -> Self::NonAtomicType
Consumes the atomic and returns the contained value. Read more
fn into_non_atomic_array<const N: usize>( data: [Self; N] ) -> [Self::NonAtomicType; N]
fn from_non_atomic_array<const N: usize>( data: [Self::NonAtomicType; N] ) -> [Self; N]
fn get_mut_slice(this: &mut [Self]) -> &mut [Self::NonAtomicType]
fn from_mut_slice(this: &mut [Self::NonAtomicType]) -> &mut [Self]
fn get_mut_array<const N: usize>( this: &mut [Self; N] ) -> &mut [Self::NonAtomicType; N]
fn from_mut_array<const N: usize>( this: &mut [Self::NonAtomicType; N] ) -> &mut [Self; N]
sourcefn compare_exchange(
&self,
current: Self::NonAtomicType,
new: Self::NonAtomicType,
success: Ordering,
failure: Ordering
) -> Result<Self::NonAtomicType, Self::NonAtomicType>
fn compare_exchange( &self, current: Self::NonAtomicType, new: Self::NonAtomicType, success: Ordering, failure: Ordering ) -> Result<Self::NonAtomicType, Self::NonAtomicType>
Stores a value into the atomic integer if the current value is the same
as the current value. Read more
sourcefn compare_exchange_weak(
&self,
current: Self::NonAtomicType,
new: Self::NonAtomicType,
success: Ordering,
failure: Ordering
) -> Result<Self::NonAtomicType, Self::NonAtomicType>
fn compare_exchange_weak( &self, current: Self::NonAtomicType, new: Self::NonAtomicType, success: Ordering, failure: Ordering ) -> Result<Self::NonAtomicType, Self::NonAtomicType>
Stores a value into the atomic integer if the current value is the same
as the current value. Read more
sourcefn swap(
&self,
value: Self::NonAtomicType,
order: Ordering
) -> Self::NonAtomicType
fn swap( &self, value: Self::NonAtomicType, order: Ordering ) -> Self::NonAtomicType
Stores a value into the atomic integer, returning the previous value. Read more
sourcefn fetch_update<F>(
&self,
set_order: Ordering,
fetch_order: Ordering,
f: F
) -> Result<Self::NonAtomicType, Self::NonAtomicType>
fn fetch_update<F>( &self, set_order: Ordering, fetch_order: Ordering, f: F ) -> Result<Self::NonAtomicType, Self::NonAtomicType>
sourceimpl AtomicNumber for AtomicF32
impl AtomicNumber for AtomicF32
sourcefn fetch_min(
&self,
value: Self::NonAtomicType,
order: Ordering
) -> Self::NonAtomicType
fn fetch_min( &self, value: Self::NonAtomicType, order: Ordering ) -> Self::NonAtomicType
Minimum with the current value. Read more
sourcefn fetch_max(
&self,
value: Self::NonAtomicType,
order: Ordering
) -> Self::NonAtomicType
fn fetch_max( &self, value: Self::NonAtomicType, order: Ordering ) -> Self::NonAtomicType
Maximum with the current value. Read more
sourcefn fetch_add(
&self,
value: Self::NonAtomicType,
order: Ordering
) -> Self::NonAtomicType
fn fetch_add( &self, value: Self::NonAtomicType, order: Ordering ) -> Self::NonAtomicType
Adds to the current value, returning the previous value. Read more
sourcefn fetch_sub(
&self,
value: Self::NonAtomicType,
order: Ordering
) -> Self::NonAtomicType
fn fetch_sub( &self, value: Self::NonAtomicType, order: Ordering ) -> Self::NonAtomicType
Subtracts from the current value, returning the previous value. Read more